ConcreteInputsFactory

Trait ConcreteInputsFactory 

pub trait ConcreteInputsFactory: LaunchArg {
    // Required method
    fn create<'a, R: Runtime>(
        client: &ComputeClient<R::Server>,
        lhs: &'a MatmulInputHandleRef<'a, R>,
        rhs: &'a MatmulInputHandleRef<'a, R>,
        bias: Option<&'a TensorHandleRef<'a, R>>,
        selection: &MatmulSelection,
        problem: &ConvolutionProblem,
        line_sizes: &MatmulLineSizes,
        config: impl ConvGemmConfig,
    ) -> Self::RuntimeArg<'a, R>;
}
Create the input runtime arguments for a matmul kernel that works on concrete inputs and output (not fused).

Required Methods

fn create<'a, R: Runtime>( client: &ComputeClient<R::Server>, lhs: &'a MatmulInputHandleRef<'a, R>, rhs: &'a MatmulInputHandleRef<'a, R>, bias: Option<&'a TensorHandleRef<'a, R>>, selection: &MatmulSelection, problem: &ConvolutionProblem, line_sizes: &MatmulLineSizes, config: impl ConvGemmConfig, ) -> Self::RuntimeArg<'a, R>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Lhs: Numeric, Rhs: Numeric, EO: Numeric> ConcreteInputsFactory for TensorInputs<Lhs, Rhs, EO>

Source

fn create<'a, R: Runtime>( client: &ComputeClient<R::Server>, lhs: &'a MatmulInputHandleRef<'a, R>, rhs: &'a MatmulInputHandleRef<'a, R>, bias: Option<&'a TensorHandleRef<'a, R>>, _selection: &MatmulSelection, problem: &ConvolutionProblem, line_sizes: &MatmulLineSizes, config: impl ConvGemmConfig, ) -> Self::RuntimeArg<'a, R>

Source

impl<Lhs: Numeric, Rhs: Numeric, EO: Numeric> ConcreteInputsFactory for TensorMapInputs<Lhs, Rhs, EO>

Source

fn create<'a, R: Runtime>( client: &ComputeClient<R::Server>, lhs: &'a MatmulInputHandleRef<'a, R>, rhs: &'a MatmulInputHandleRef<'a, R>, bias: Option<&'a TensorHandleRef<'a, R>>, selection: &MatmulSelection, problem: &ConvolutionProblem, line_sizes: &MatmulLineSizes, config: impl ConvGemmConfig, ) -> Self::RuntimeArg<'a, R>

Implementors